package com.lwitz.entities;

import org.mini2Dx.core.engine.geom.CollisionPoint;
import org.mini2Dx.core.game.GameContainer;
import org.mini2Dx.core.graphics.Graphics;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input.Keys;

public class Player extends Entity{
	public static final int TEXTURE_WIDTH = 100;
	public static final int TEXTURE_HEIGHT = 100;
	private float punchInterval;
	private float cooldown;
	private float moveSpeed;
	
	public Player(CollisionPoint pos, EntityState state){
		super(pos, state);
		punchInterval = 5f;
		cooldown = 0f;
		moveSpeed = 220f;
	}
	
	public void update(GameContainer gc, float delta){
		if(Gdx.input.isKeyPressed(Keys.LEFT) && pos.getX() > 0){
			pos.setX(pos.getX() - moveSpeed * delta);
		}
		if(Gdx.input.isKeyPressed(Keys.RIGHT) && pos.getX() + TEXTURE_WIDTH < gc.getWidth()){
			pos.setX(pos.getX() + moveSpeed * delta);
		}
		if(state != null){
			EntityState returned = state.update(gc, pos, delta);
			if(returned != null){
				if(returned instanceof PunchState){
					tryPunch((PunchState)returned);
				} else {
					this.state = returned;
				}
			}
		}
		if(state instanceof WaveState){
			cooldown -= delta;
			if(cooldown < 0)
				cooldown = 0;
		}
	}
	
	private void tryPunch(PunchState ps){
		if(canPunch()){
			this.state = ps;
			cooldown = punchInterval;
		}
	}
	
	private boolean canPunch(){
		return (cooldown < 0.001);
	}
	
	public void render(GameContainer gc, Graphics g){
		if(state != null){
			state.render(gc, pos, g);
		}
		g.drawRect(pos.getX(), pos.getY(), TEXTURE_WIDTH, TEXTURE_HEIGHT);
		renderChargeBar(gc, g);
	}
	
	public void renderChargeBar(GameContainer gc, Graphics g){
		g.drawRect(gc.getWidth()/4, 9/10f * gc.getHeight(), gc.getWidth() / 2, 50);
		g.fillRect(gc.getWidth()/4, 9/10f * gc.getHeight(), gc.getWidth() / 2 * (punchInterval - cooldown)/punchInterval, 50);
	}
	
	public CollisionPoint getPos(){
		return pos;
	}
	
	public boolean isPunching(){
		return (state instanceof PunchState);
	}
	
}
