package com.lwitz.entities;

import org.mini2Dx.core.engine.geom.CollisionPoint;
import org.mini2Dx.core.game.GameContainer;
import org.mini2Dx.core.graphics.Graphics;
import org.mini2Dx.core.graphics.Sprite;

import com.badlogic.gdx.graphics.Texture;

public class Scissor implements Enemy{
	private Sprite sprite;
	private float radians;
	private float startX;
	private float xSpeed;
	private float ySpeed;
	private float tolerance;
	private float radianScaling;
	
	public Scissor(GameContainer gc){
		xSpeed = 60;
		ySpeed = 200;
		sprite = new Sprite(new Texture("enemy.png"));
		startX = (float)(Math.random() * (gc.getWidth() - sprite.getWidth()) - sprite.getWidth()/2);
		sprite.setPosition(startX, -(sprite.getHeight()));
		tolerance = 7;
		radianScaling = (float)((Math.random() * 1.5) + 0.5);
	}
	
	public boolean update(GameContainer gc, float delta){
		radians = (float) ((radians + radianScaling * delta) % (Math.PI * 2));
		sprite.setX((float) (startX + xSpeed * Math.sin(2 * radians)));
		sprite.setY(sprite.getY() + ySpeed * delta);
		if(sprite.getY() > gc.getHeight())
			return true;
		return false;
	}
	
	public void render(GameContainer gc, Graphics g){
		//g.drawSprite(sprite);
		g.rotate((float) (20*(Math.sin(radians))), sprite.getX() + sprite.getWidth()/2, sprite.getY() + sprite.getHeight()/2);
		g.drawSprite(sprite);
		g.setRotation(0, sprite.getX() + sprite.getWidth()/2, sprite.getY() + sprite.getHeight()/2);
		
		g.drawRect(sprite.getX() + 2 * tolerance, sprite.getY() + 4 * tolerance, sprite.getWidth() - 4 * tolerance, sprite.getHeight() - 5 * tolerance);
	}
	
	public boolean checkCollision(CollisionPoint pos, int width, int height){
		if(sprite.getY() + sprite.getHeight() - tolerance > pos.y && sprite.getY() + 4 * tolerance < pos.y + height){
			if(sprite.getX() + sprite.getWidth() - 2 * tolerance > pos.x && sprite.getX() + 2 * tolerance < pos.x + width){
				return true;
			}
		}
		return false;
	}
}
