package com.lwitz.screens;

import org.mini2Dx.core.game.GameContainer;
import org.mini2Dx.core.graphics.Graphics;
import org.mini2Dx.core.screen.BasicGameScreen;
import org.mini2Dx.core.screen.GameScreen;
import org.mini2Dx.core.screen.ScreenManager;
import org.mini2Dx.core.screen.transition.FadeInTransition;
import org.mini2Dx.core.screen.transition.FadeOutTransition;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.audio.Music;

// Displays a loading message on launch for four seconds,
// 		then transitions to the TitleScreen
// 01.21.17 Leon Witzman
public class LoadingScreen extends BasicGameScreen{
	public static final int ID = 0;
	
	private float loadTime = 4f;
	private Music song;
	
	@Override
	public void initialise(GameContainer gc) {
		song = Gdx.audio.newMusic(Gdx.files.internal("song.wav"));
		song.setLooping(true);
	}

	@Override
	public void update(GameContainer gc, ScreenManager<? extends GameScreen> screenManager, float delta) {
		if (loadTime > 0f){
			loadTime -= delta;
			if(loadTime <= 0f){
				screenManager.enterGameScreen(TitleScreen.ID, new FadeOutTransition(), 
						new FadeInTransition());
				song.play();
			}
		}
	}

	@Override
	public void interpolate(GameContainer gc, float alpha) {
		
	}

	@Override
	public void render(GameContainer gc, Graphics g) {
		g.drawString("Preparing Epic Game", gc.getWidth() / 2 - 65, 
				gc.getHeight() / 2 - 10);
		
		for(int i = 0; i < (4 - (int)loadTime); i++){
			g.drawString(".", gc.getWidth()/2 + i*67 - 100, gc.getHeight()/2 + 20);
		}
	}

	@Override
	public int getId() {
		return ID;
	}

}
