package com.lwitz.screens;

import java.util.ArrayList;

import org.mini2Dx.core.engine.geom.CollisionPoint;
import org.mini2Dx.core.game.GameContainer;
import org.mini2Dx.core.graphics.Graphics;
import org.mini2Dx.core.screen.BasicGameScreen;
import org.mini2Dx.core.screen.ScreenManager;

import com.lwitz.entities.Scissor;
import com.lwitz.entities.Enemy;
import com.lwitz.entities.Player;
import com.lwitz.entities.WaveState;
import com.lwitz.entities.Weight;

public class PlayScreen extends BasicGameScreen{
	public static int ID = 2;
	private Player player;
	private float beatInterval = 1f;
	private float beatTimer;
	private ArrayList<Enemy> enemies;
	private float shakeDuration = 0.25f;
	private float shakeTimer = 0;
	private float score;

	@Override
	public void initialise(GameContainer gc) {
		score = 0;
		player = new Player(new CollisionPoint((gc.getWidth() - Player.TEXTURE_WIDTH) / 2, 3/4f * (gc.getHeight())), 
				new WaveState());
		beatTimer = 0;
		enemies = new ArrayList<Enemy>();
	}

	@Override
	public void update(GameContainer gc, ScreenManager<? extends org.mini2Dx.core.screen.GameScreen> screenManager,
			float delta) {
		player.update(gc, delta);
		for(int i = 0; i < enemies.size(); i++){
			Enemy e = enemies.get(i);
			if(e.update(gc, delta)){
				enemies.remove(i);
			}
			if(e.checkCollision(player.getPos(), Player.TEXTURE_WIDTH, Player.TEXTURE_HEIGHT)){
				if(player.isPunching()){
					shakeTimer = shakeDuration;
					enemies.remove(i);
				} else {
					initialise(gc);
				}
			}
		}
		shakeTimer -= delta;
		if(shakeTimer < 0){
			shakeTimer = 0;
		}
		score += delta;
		beatTimer += delta;
		if(beatTimer > beatInterval){
			beatTimer = 0;
			double roll = Math.random();
			if(roll < 0.2){
				enemies.add(new Weight(gc));
			} else if (roll < 0.9) {
				enemies.add(new Scissor(gc));
			}
		}
	}

	@Override
	public void interpolate(GameContainer gc, float alpha) {
		player.interpolate(gc, alpha);
	}

	@Override
	public void render(GameContainer gc, Graphics g) {
		g.drawString("SCORE: " + (int)(score * 2), 10, 10);
		if(shakeTimer > 0.001){
			g.setTranslation((float)(15*Math.random()), (float) (10*Math.random()));;
		} else {
			g.setTranslation(0, 0);
		}
		player.render(gc, g);
		for(Enemy e : enemies)
			e.render(gc, g);
	}

	@Override
	public int getId() {
		// TODO Auto-generated method stub
		return ID;
	}

}
