package com.lwitz.screens;

import org.mini2Dx.core.game.GameContainer;
import org.mini2Dx.core.graphics.Graphics;
import org.mini2Dx.core.graphics.Sprite;
import org.mini2Dx.core.screen.BasicGameScreen;
import org.mini2Dx.core.screen.GameScreen;
import org.mini2Dx.core.screen.ScreenManager;
import org.mini2Dx.core.screen.transition.FadeInTransition;
import org.mini2Dx.core.screen.transition.FadeOutTransition;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input.Keys;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.Texture;

// Displays game title and waits for user input,
//     then transitions to GameScreen
// 01.21.17 Leon Witzman
public class TitleScreen extends BasicGameScreen{
	public static final int ID = 1;
	private Sprite logo;
	private Texture title;
	private float elapsedTime;
	
	@Override
	public void initialise(GameContainer gc) {
		elapsedTime = 0;
		logo = new Sprite(new Texture("mini2Dx.png"));
		title = new Texture("title.gif");
		updateLogo(gc);
	}

	@Override
	public void update(GameContainer gc, ScreenManager<? extends GameScreen> screenManager, float delta) {
		elapsedTime = (float)((elapsedTime + 2 * delta) % (2*Math.PI));
		updateLogo(gc);
		if (Gdx.input.isKeyJustPressed(Keys.SPACE))
			screenManager.enterGameScreen(PlayScreen.ID, new FadeOutTransition(), 
					new FadeInTransition());
	}

	@Override
	public void interpolate(GameContainer gc, float alpha) {
	}

	@Override
	public void render(GameContainer gc, Graphics g) {
		g.setBackgroundColor(Color.LIGHT_GRAY);
		g.drawSprite(logo);
		g.drawTexture(title, (gc.getWidth() - title.getWidth())/2, (float) ((gc.getHeight() - title.getHeight())/2 
				+ gc.getWidth()/20 * Math.sin(elapsedTime)));
		if (elapsedTime % (Math.PI / 2) < (Math.PI / 4)){
			Color old = g.getColor();
			g.setColor(Color.BLACK);
			g.drawString("Press Space to Begin", gc.getWidth()/2 - 80, 5 * gc.getHeight() / 6);
			g.setColor(old);
		}
	}

	@Override
	public int getId() {
		return ID;
	}
	
	private void updateLogo(GameContainer gc){
		logo.setX((float) ((gc.getWidth() - logo.getWidth())/2 + gc.getWidth()/20 * Math.sin(elapsedTime)));
		logo.setY(gc.getHeight() / 4 - logo.getHeight());
	}

}
